==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QAlphaTest.java <==
package io.qt.qt3d.render;


/**
 * <p>Specify alpha reference test</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html">Qt3DRender::QAlphaTest</a></p>
 */
public class QAlphaTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAlphaTest.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html#AlphaFunction-enum">Qt3DRender::QAlphaTest::AlphaFunction</a></p>
     */
    public enum AlphaFunction implements io.qt.QtEnumerator {
        Never(512),
        Always(519),
        Less(513),
        LessOrEqual(515),
        Equal(514),
        GreaterOrEqual(518),
        Greater(516),
        NotEqual(517);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private AlphaFunction(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static AlphaFunction resolve(int value) {
            switch (value) {
            case 512: return Never;
            case 519: return Always;
            case 513: return Less;
            case 515: return LessOrEqual;
            case 514: return Equal;
            case 518: return GreaterOrEqual;
            case 516: return Greater;
            case 517: return NotEqual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html#alphaFunction-prop">Qt3DRender::QAlphaTest::alphaFunctionChanged(Qt3DRender::QAlphaTest::AlphaFunction)</a></p>
     */
    @io.qt.QtPropertyNotify(name="alphaFunction")
    public final Signal1<io.qt.qt3d.render.QAlphaTest.AlphaFunction> alphaFunctionChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html#referenceValue-prop">Qt3DRender::QAlphaTest::referenceValueChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="referenceValue")
    public final Signal1<@io.qt.QtPrimitiveType Float> referenceValueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAlphaTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAlphaTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QAlphaTest(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAlphaTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html#alphaFunction-prop">Qt3DRender::QAlphaTest::alphaFunction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="alphaFunction")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAlphaTest.AlphaFunction alphaFunction(){
        return io.qt.qt3d.render.QAlphaTest.AlphaFunction.resolve(alphaFunction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int alphaFunction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html#referenceValue-prop">Qt3DRender::QAlphaTest::referenceValue()const</a></p>
     */
    @io.qt.QtPropertyReader(name="referenceValue")
    @io.qt.QtUninvokable
    public final float referenceValue(){
        return referenceValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float referenceValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html#alphaFunction-prop">Qt3DRender::QAlphaTest::setAlphaFunction(Qt3DRender::QAlphaTest::AlphaFunction)</a></p>
     */
    @io.qt.QtPropertyWriter(name="alphaFunction")
    public final void setAlphaFunction(io.qt.qt3d.render.QAlphaTest.AlphaFunction alphaFunction){
        setAlphaFunction_native_Qt3DRender_QAlphaTest_AlphaFunction(QtJambi_LibraryUtilities.internal.nativeId(this), alphaFunction.value());
    }
    
    private native void setAlphaFunction_native_Qt3DRender_QAlphaTest_AlphaFunction(long __this__nativeId, int alphaFunction);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qalphatest.html#referenceValue-prop">Qt3DRender::QAlphaTest::setReferenceValue(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="referenceValue")
    public final void setReferenceValue(float referenceValue){
        setReferenceValue_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), referenceValue);
    }
    
    private native void setReferenceValue_native_float(long __this__nativeId, float referenceValue);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAlphaTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAlphaTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAlphaTest instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.9-sources.jar: io/qt/qt3d/render/QAlphaTest.java <==
package io.qt.qt3d.render;


/**
 * <p>Specify alpha reference test</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html">Qt3DRender::QAlphaTest</a></p>
 */
public class QAlphaTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAlphaTest.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html#AlphaFunction-enum">Qt3DRender::QAlphaTest::AlphaFunction</a></p>
     */
    public enum AlphaFunction implements io.qt.QtEnumerator {
        Never(512),
        Always(519),
        Less(513),
        LessOrEqual(515),
        Equal(514),
        GreaterOrEqual(518),
        Greater(516),
        NotEqual(517);

        private AlphaFunction(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static AlphaFunction resolve(int value) {
            switch (value) {
            case 512: return Never;
            case 519: return Always;
            case 513: return Less;
            case 515: return LessOrEqual;
            case 514: return Equal;
            case 518: return GreaterOrEqual;
            case 516: return Greater;
            case 517: return NotEqual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html#alphaFunction-prop">Qt3DRender::QAlphaTest::alphaFunctionChanged(Qt3DRender::QAlphaTest::AlphaFunction)</a></p>
     */
    @io.qt.QtPropertyNotify(name="alphaFunction")
    public final Signal1<io.qt.qt3d.render.QAlphaTest.AlphaFunction> alphaFunctionChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html#referenceValue-prop">Qt3DRender::QAlphaTest::referenceValueChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="referenceValue")
    public final Signal1<@io.qt.QtPrimitiveType Float> referenceValueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAlphaTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAlphaTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QAlphaTest(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAlphaTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html#alphaFunction-prop">Qt3DRender::QAlphaTest::alphaFunction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="alphaFunction")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAlphaTest.AlphaFunction alphaFunction(){
        return io.qt.qt3d.render.QAlphaTest.AlphaFunction.resolve(alphaFunction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int alphaFunction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html#referenceValue-prop">Qt3DRender::QAlphaTest::referenceValue()const</a></p>
     */
    @io.qt.QtPropertyReader(name="referenceValue")
    @io.qt.QtUninvokable
    public final float referenceValue(){
        return referenceValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float referenceValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html#alphaFunction-prop">Qt3DRender::QAlphaTest::setAlphaFunction(Qt3DRender::QAlphaTest::AlphaFunction)</a></p>
     */
    @io.qt.QtPropertyWriter(name="alphaFunction")
    public final void setAlphaFunction(io.qt.qt3d.render.QAlphaTest.AlphaFunction alphaFunction){
        setAlphaFunction_native_Qt3DRender_QAlphaTest_AlphaFunction(QtJambi_LibraryUtilities.internal.nativeId(this), alphaFunction.value());
    }
    
    private native void setAlphaFunction_native_Qt3DRender_QAlphaTest_AlphaFunction(long __this__nativeId, int alphaFunction);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qalphatest.html#referenceValue-prop">Qt3DRender::QAlphaTest::setReferenceValue(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="referenceValue")
    public final void setReferenceValue(float referenceValue){
        setReferenceValue_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), referenceValue);
    }
    
    private native void setReferenceValue_native_float(long __this__nativeId, float referenceValue);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAlphaTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAlphaTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAlphaTest instance, QDeclarativeConstructor constructor);
    
}
